"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExcelCreatorCustomizer = void 0;
class ExcelCreatorCustomizer {
    custom(element, structure) {
        if (!structure)
            return element;
        let formattedValue = element;
        if (structure.type === "options" /* OPTIONS */ && structure.options)
            this.validOptionsValue(element, structure.options);
        if (structure.customFormat)
            formattedValue = this.formatValue(element, structure.customFormat);
        if (structure.customFormatCallback)
            formattedValue = structure.customFormatCallback(formattedValue);
        return formattedValue;
    }
    validOptionsValue(value, customOptions) {
        const isValid = customOptions.includes(value);
        if (!isValid)
            throw new Error("The element row is not in options custom items");
    }
    formatValue(value, customFormat) {
        var _a;
        switch (customFormat) {
            case "123" /* NUMBER */:
                return value.toString();
            case "mmm - yy" /* DATE */: {
                const date = new Date(value);
                const month = date.getMonth();
                const year = date.getFullYear();
                return `${month} - ${year}`;
            }
            case "dd - mm - yyyy" /* FULL_DATE */: {
                const date = new Date(value);
                const day = date.getDate().toString().padStart(2, '0');
                const month = (date.getMonth() + 1).toString().padStart(2, '0');
                const year = date.getFullYear();
                return `${day} - ${month} - ${year}`;
            }
            case "R$ 0.00" /* MONEY */:
                return parseFloat(value).toLocaleString("pt-BR", {
                    style: "currency",
                    currency: "BRL",
                });
            case "0%" /* PERCENTAGE */:
                return `${value}%`;
            case "0" /* ZERO_DEFAULT */:
                return (_a = value.toString()) !== null && _a !== void 0 ? _a : "0";
            default:
                return value;
        }
    }
}
exports.ExcelCreatorCustomizer = ExcelCreatorCustomizer;
