"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExcelParser = void 0;
const node_xlsx_1 = __importDefault(require("node-xlsx"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const sheetExcelParser_1 = require("./sheetExcelParser");
const logger_1 = require("../../logger");
class ExcelParser {
    async parse(data) {
        try {
            logger_1.logger.info("ExcelParser initiated", { context: data });
            const filePath = path_1.default.resolve(data.rootDirname, "uploads", `${data.filename}`);
            const sheets = node_xlsx_1.default.parse(filePath);
            const parsedResult = sheets.map((sheet) => new sheetExcelParser_1.SheetExcelParser().parse(sheet));
            await this.deleteFile(filePath);
            logger_1.logger.info("ExcelParser finished", { context: data });
            return parsedResult;
        }
        catch (error) {
            logger_1.logger.error("ExcelParser failed", { context: data, error });
            throw error;
        }
    }
    async deleteFile(path) {
        await fs_1.default.promises.stat(path);
        await fs_1.default.promises.unlink(path);
    }
}
exports.ExcelParser = ExcelParser;
