import winston from "winston";
export interface ILoggerConfigs {
    /**
     * (Opcional)
     * Configurações aplicadas aos logs que serão exibidos no console.
     * Para mais detalhes, veja a documentação oficial do winston (https://github.com/winstonjs/winston/blob/master/docs/transports.md#console-transport).
     * Caso não informado, a opção de logs pelo console será desativada.
     */
    console?: winston.transports.ConsoleTransportOptions;
    /**
     * (Opcional)
     * Configurações aplicadas aos logs que serão gravadas em arquivos.
     * Para mais detalhes, veja a documentação oficial do winston (https://github.com/winstonjs/winston/blob/master/docs/transports.md#file-transport).
     * Caso não informado, a opção de logs em arquivos será desativada.
     */
    file?: winston.transports.FileTransportOptions;
    /**
     * (Opcional)
     * Array de strings dos headers que serão removidos dos logs no objeto de requisição.
     */
    confidentialHeaders?: string[];
    /**
     * (Opcional)
     * Array de strings das rotas a serem removidas totalmento dos logs (tanto a requisição, quanto a resposta).
     * Caso a rota possua algum parâmetro, é necessário informalo iniciando em :.
     * Exemplo: [`/offers/:offerId/details`, `/offers/list`, `/users/:user_id`].
     */
    ignoredRoutes?: string[];
    /**
   * (Opcional)
   * Array de strings dos parâmetros do objeto de requisição a serem logados.
   * Caso nenhum valor seja passado, somente o body será exibido por padrão.
   */
    requestWhitelist?: string[];
    /**
     * (Opcional)
     * Array de strings dos parâmetros do objeto de resposta a serem logados.
     * Caso nenhum valor seja passado, somente o body será exibido por padrão.
     */
    responseWhitelist?: string[];
    /**
     * (Opcional)
     * Array de objetos contendo as rotas e métodos, referente as chamadas das quais
     * o parâmetro body será omitido no objeto de resposta nos logs.
     * Caso a rota possua algum parâmetro, é necessário informalo iniciando em :.
     * Exemplo: [{ route: `offers/:offerId/details`, method: `POST` }]
     */
    responseBlacklistBodyRoutes?: Array<{
        route: string;
        method: string;
    }>;
    /**
     * (Opcional)
     * Array de objetos contendo as rotas e métodos, referente as chamadas das quais
     * o parâmetro body será omitido no objeto de requisiçao nos logs.
     * Caso a rota possua algum parâmetro, é necessário informalo iniciando em :.
     * Exemplo: [{ route: `offers/:offerId/details`, method: `POST` }]
     */
    requestBlacklistBodyRoutes?: Array<{
        route: string;
        method: string;
    }>;
}
